@@ -27,19 +27,25 @@ model_spec <- arima_reg(
 
 # * NO XREGS ----
 
-# Fit Spec
-model_fit <- model_spec %>%
-    fit(log(value) ~ date, data = training(splits))
-
-# Predictions
-predictions_tbl <- model_fit %>%
-    modeltime_calibrate(testing(splits)) %>%
-    modeltime_forecast(new_data = testing(splits))
-
 
 # TESTS
 test_that("arima_reg: Arima, (No xregs), Test Model Fit Object", {
 
+
+    testthat::skip_on_cran()
+
+    #
+
+
+    # Fit Spec
+    model_fit <- model_spec %>%
+        fit(log(value) ~ date, data = training(splits))
+
+    # Predictions
+    predictions_tbl <- model_fit %>%
+        modeltime_calibrate(testing(splits)) %>%
+        modeltime_forecast(new_data = testing(splits))
+
     testthat::expect_s3_class(model_fit$fit, "Arima_fit_impl")
 
     # $fit
@@ -56,9 +62,8 @@ test_that("arima_reg: Arima, (No xregs), Test Model Fit Object", {
 
     testthat::expect_equal(model_fit$preproc$y_var, "value")
 
-})
 
-test_that("arima_reg: Arima, (No xregs), Test Predictions", {
+    # arima_reg: Arima, (No xregs), Test Predictions
 
     # Structure
     testthat::expect_identical(nrow(testing(splits)), nrow(predictions_tbl))
@@ -78,19 +83,23 @@ test_that("arima_reg: Arima, (No xregs), Test Predictions", {
 
 # * XREGS ----
 
-# Fit Spec
-model_fit <- model_spec %>%
-    fit(log(value) ~ date + month(date, label = TRUE), data = training(splits))
-
-# Predictions
-predictions_tbl <- model_fit %>%
-    modeltime_calibrate(testing(splits)) %>%
-    modeltime_forecast(new_data = testing(splits))
-
-
 # TESTS
 test_that("arima_reg: Arima, (XREGS), Test Model Fit Object", {
 
+    testthat::skip_on_cran()
+
+    #
+
+    # Fit Spec
+    model_fit <- model_spec %>%
+        fit(log(value) ~ date + month(date, label = TRUE), data = training(splits))
+
+    # Predictions
+    predictions_tbl <- model_fit %>%
+        modeltime_calibrate(testing(splits)) %>%
+        modeltime_forecast(new_data = testing(splits))
+
+
     testthat::expect_s3_class(model_fit$fit, "Arima_fit_impl")
 
     # $fit
@@ -107,9 +116,8 @@ test_that("arima_reg: Arima, (XREGS), Test Model Fit Object", {
 
     testthat::expect_equal(model_fit$preproc$y_var, "value")
 
-})
 
-test_that("arima_reg: Arima (XREGS), Test Predictions", {
+    # arima_reg: Arima (XREGS), Test Predictions
 
     # Structure
     testthat::expect_identical(nrow(testing(splits)), nrow(predictions_tbl))
@@ -130,41 +138,44 @@ test_that("arima_reg: Arima (XREGS), Test Predictions", {
 
 # ---- WORKFLOWS ----
 
-# Model Spec
-model_spec <- arima_reg(
-    seasonal_period          = 12,
-    non_seasonal_ar          = 3,
-    non_seasonal_differences = 1,
-    non_seasonal_ma          = 3,
-    seasonal_ar              = 1,
-    seasonal_differences     = 0,
-    seasonal_ma              = 1
-) %>%
-    set_engine("arima")
-
-# Recipe spec
-recipe_spec <- recipe(value ~ date, data = training(splits)) %>%
-    step_log(value, skip = FALSE)
-
-# Workflow
-wflw <- workflow() %>%
-    add_recipe(recipe_spec) %>%
-    add_model(model_spec)
-
-wflw_fit <- wflw %>%
-    fit(training(splits))
-
-# Forecast
-predictions_tbl <- wflw_fit %>%
-    modeltime_calibrate(testing(splits)) %>%
-    modeltime_forecast(new_data = testing(splits), actual_data = training(splits)) %>%
-    mutate_at(vars(.value), exp)
-
-
-
 # TESTS
 test_that("arima_reg: Arima (workflow), Test Model Fit Object", {
 
+
+    testthat::skip_on_cran()
+
+
+    # Model Spec
+    model_spec <- arima_reg(
+        seasonal_period          = 12,
+        non_seasonal_ar          = 3,
+        non_seasonal_differences = 1,
+        non_seasonal_ma          = 3,
+        seasonal_ar              = 1,
+        seasonal_differences     = 0,
+        seasonal_ma              = 1
+    ) %>%
+        set_engine("arima")
+
+    # Recipe spec
+    recipe_spec <- recipe(value ~ date, data = training(splits)) %>%
+        step_log(value, skip = FALSE)
+
+    # Workflow
+    wflw <- workflow() %>%
+        add_recipe(recipe_spec) %>%
+        add_model(model_spec)
+
+    wflw_fit <- wflw %>%
+        fit(training(splits))
+
+    # Forecast
+    predictions_tbl <- wflw_fit %>%
+        modeltime_calibrate(testing(splits)) %>%
+        modeltime_forecast(new_data = testing(splits), actual_data = training(splits)) %>%
+        mutate_at(vars(.value), exp)
+
+
     testthat::expect_s3_class(wflw_fit$fit$fit$fit, "Arima_fit_impl")
 
     # $fit
@@ -181,9 +192,8 @@ test_that("arima_reg: Arima (workflow), Test Model Fit Object", {
     mld <- wflw_fit %>% workflows::extract_mold()
     testthat::expect_equal(names(mld$outcomes), "value")
 
-})
 
-test_that("arima_reg: Arima (workflow), Test Predictions", {
+    # arima_reg: Arima (workflow), Test Predictions
 
     full_data <- bind_rows(training(splits), testing(splits))
 
