@@ -1,50 +1,55 @@
 context("PANEL DATA")
 
-# SETUP ----
-
-m4_monthly_jumbled <- m4_monthly %>%
-    arrange(desc(date))
-
-data_set <- m4_monthly_jumbled
-
-recipe_spec <- recipe(value ~ date + id, data_set) %>%
-    step_mutate(date_num = as.numeric(date)) %>%
-    step_mutate(month_lbl = lubridate::month(date, label = TRUE)) %>%
-    step_dummy(all_nominal(), one_hot = TRUE)
-
-set.seed(123)
-wflw_fit_prophet <- workflow() %>%
-    add_model(
-        prophet_boost(
-            seasonality_yearly = F,
-            seasonality_weekly = F,
-            seasonality_daily  = F
-        ) %>%
-            set_engine(
-                "prophet_xgboost"
-                # ,
-                # colsample_bytree = 1
-            )
-    ) %>%
-    add_recipe(recipe_spec) %>%
-    fit(data_set)
-
-set.seed(123)
-wflw_fit_svm <- workflow() %>%
-    add_model(svm_rbf(mode = "regression") %>% set_engine("kernlab")) %>%
-    add_recipe(recipe_spec %>% step_rm(date)) %>%
-    fit(data_set)
-
-# set.seed(123)
-# wflw_fit_xgb <- workflow() %>%
-#     add_model(boost_tree() %>% set_engine("xgboost")) %>%
-#     add_recipe(recipe_spec %>% step_rm(date)) %>%
-#     fit(data_set)
 
 # PANEL DATA - FORECAST JUMBLED ----
 
 test_that("Panel Data - Forecast Jumbled", {
 
+    testthat::skip_on_cran()
+
+    #
+
+    m4_monthly_jumbled <- m4_monthly %>%
+        arrange(desc(date))
+
+    data_set <- m4_monthly_jumbled
+
+    recipe_spec <- recipe(value ~ date + id, data_set) %>%
+        step_mutate(date_num = as.numeric(date)) %>%
+        step_mutate(month_lbl = lubridate::month(date, label = TRUE)) %>%
+        step_dummy(all_nominal(), one_hot = TRUE)
+
+    set.seed(123)
+    wflw_fit_prophet <- workflow() %>%
+        add_model(
+            prophet_boost(
+                seasonality_yearly = F,
+                seasonality_weekly = F,
+                seasonality_daily  = F
+            ) %>%
+                set_engine(
+                    "prophet_xgboost"
+                    # ,
+                    # colsample_bytree = 1
+                )
+        ) %>%
+        add_recipe(recipe_spec) %>%
+        fit(data_set)
+
+    set.seed(123)
+    wflw_fit_svm <- workflow() %>%
+        add_model(svm_rbf(mode = "regression") %>% set_engine("kernlab")) %>%
+        add_recipe(recipe_spec %>% step_rm(date)) %>%
+        fit(data_set)
+
+    # set.seed(123)
+    # wflw_fit_xgb <- workflow() %>%
+    #     add_model(boost_tree() %>% set_engine("xgboost")) %>%
+    #     add_recipe(recipe_spec %>% step_rm(date)) %>%
+    #     fit(data_set)
+
+    # Panel Data - Forecast Jumbled
+
     model_tbl <- modeltime_table(
         wflw_fit_prophet,
         wflw_fit_svm
@@ -90,11 +95,8 @@ test_that("Panel Data - Forecast Jumbled", {
     expect_equal(nrow(svm_tbl), nrow(data_set))
     expect_equal(svm_tbl$.index, svm_tbl$date)
 
-})
 
-# ERROR CHECKS ----
-
-test_that("Panel Data - Error Checks", {
+    # Panel Data - Error Checks
 
     # Using h with overlapping actual data
     expect_error({
